==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebActiveStepChangedArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActiveStepChangedArgsDetailDescription } from "./WebActiveStepChangedArgsDetailDescription";
/**
 * @hidden
 */
export let WebActiveStepChangedArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebActiveStepChangedArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebActiveStepChangedArgsDetailDescriptionMetadata.a == null) {
                WebActiveStepChangedArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebActiveStepChangedArgsDetailDescriptionMetadata.c(WebActiveStepChangedArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebActiveStepChangedArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebActiveStepChangedArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ActiveStepChangedArgsDetail");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__skipSuffix", "Boolean");
            a.item("Index", "Number:double");
        }
        static d(a) {
            WebActiveStepChangedArgsDetailDescriptionMetadata.b(a);
            a.ad("WebActiveStepChangedArgsDetail", () => new WebActiveStepChangedArgsDetailDescription());
            a.ac("WebActiveStepChangedArgsDetail", WebActiveStepChangedArgsDetailDescriptionMetadata.a);
        }
    }
    WebActiveStepChangedArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebActiveStepChangedArgsDetailDescriptionMetadata, 'WebActiveStepChangedArgsDetailDescriptionMetadata');
    WebActiveStepChangedArgsDetailDescriptionMetadata.a = null;
    return WebActiveStepChangedArgsDetailDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebActiveStepChangedArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActiveStepChangedArgsDetailDescription } from "./WebActiveStepChangedArgsDetailDescription";
/**
 * @hidden
 */
export let WebActiveStepChangedArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebActiveStepChangedArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebActiveStepChangedArgsDetailDescriptionMetadata.a == null) {
                WebActiveStepChangedArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebActiveStepChangedArgsDetailDescriptionMetadata.c(WebActiveStepChangedArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebActiveStepChangedArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebActiveStepChangedArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ActiveStepChangedArgsDetail");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Index", "Number:double");
        }
        static d(a) {
            WebActiveStepChangedArgsDetailDescriptionMetadata.b(a);
            a.ae("WebActiveStepChangedArgsDetail", () => new WebActiveStepChangedArgsDetailDescription());
            a.ad("WebActiveStepChangedArgsDetail", WebActiveStepChangedArgsDetailDescriptionMetadata.a);
        }
    }
    WebActiveStepChangedArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebActiveStepChangedArgsDetailDescriptionMetadata, 'WebActiveStepChangedArgsDetailDescriptionMetadata');
    WebActiveStepChangedArgsDetailDescriptionMetadata.a = null;
    return WebActiveStepChangedArgsDetailDescriptionMetadata;
})();
